netapp_ontap.models.vscan_on_demand_scope API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.vscan_on_demand_scope`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class VscanOnDemandScopeSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the VscanOnDemandScope object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `exclude_extensions: List[str] GET POST PATCH`

    List of file extensions for which scanning is not performed.

    Example: ["mp3","mp4"]

  `exclude_paths: List[str] GET POST PATCH`

    List of file paths for which scanning must not be performed.

    Example: ["/vol1/cold-files/","/vol1/cifs/names"]

  `include_extensions: List[str] GET POST PATCH`

    List of file extensions to be scanned.

    Example: ["vmdk","mp*"]

  `max_file_size: Size GET POST PATCH`

    Maximum file size, in bytes, allowed for scanning.

    Example: 10737418240

  `scan_without_extension: bool GET POST PATCH`

    Specifies whether or not files without any extension can be scanned.